#!/usr/bin/env python
from __future__ import division, absolute_import, print_function

import os
import sys
import unittest


cwd = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, cwd)

from podcasts import Podcast

source = os.path.join(cwd, "test", "fixtures", "shoutengine.xml")

_copyright = None
_type = None
author = "Matt Farah & Zack Klapman"
categories = ['Automotive', 'Comedy', 'Games & Hobbies', 'Video Games']
description = "Matt Farah and Zack Klapman sit down with automotive icons, pro drivers, comedians and other friends to discuss automotive industry news, racing, projects and whatever else comes to mind.For video test drives and reviews, go toTheSmokingTire.comorwww.youtube.com/thesmokingtireRentour movie, where we find out if some bad CraigsList cars can cross an entire US State, off-road!www.thesmokingtire.com/film"
explicit = "yes"
generator = "ShoutEngine 1.0; http://www.shoutengine.com"
image_url = "http://media.cdn.shoutengine.com/cache/d6/e9/d6e900686dd88c35c643f0a1747f1912.jpg"
language = "en"
last_build_date = "Sat, 11 May 2019 19:21:22"
link = 'http://shoutengine.com/TheSmokingTire/'
managing_editor = "Matt Farah & Zack Klapman"
new_feed_url = None
owner = "Matt Farah & Zack Klapman"
pub_date = "Fri, 01 Mar 2013 22:12:55 +0000"
subtitle = "Matt Farah and Zack Klapman sit down with automotive icons, pro drivers, comedians and other friends to discuss automotive industry news, racing, projects and whatever else comes to mind.For video test drives and reviews, go toTheSmokingTire.comorwww.youtube.com/thesmokingtireRentour movie, where we find out if some bad CraigsList cars can cross an entire US State, off-road!www.thesmokingtire.com/film"
summary = "Matt Farah and Zack Klapman sit down with automotive icons, pro drivers, comedians and other friends to discuss automotive industry news, racing, projects and whatever else comes to mind.For video test drives and reviews, go toTheSmokingTire.comorwww.youtube.com/thesmokingtireRentour movie, where we find out if some bad CraigsList cars can cross an entire US State, off-road!www.thesmokingtire.com/film"
title = "The Smoking Tire"
web_master = "Matt Farah & Zack Klapman"

class TestShoutengine(unittest.TestCase):
    def setUp(self):
        self.podcast = Podcast(source)

    def test_attrubites(self):

        self.assertEqual(self.podcast.source, source)
        self.assertEqual(self.podcast.author, author)
        self.assertEqual(self.podcast.categories, categories)
        self.assertEqual(self.podcast.copyright, _copyright)
        self.assertEqual(self.podcast.description, description)
        self.assertEqual(self.podcast.explicit, explicit)
        self.assertEqual(self.podcast.generator, generator)
        self.assertEqual(self.podcast.image_url, image_url)
        self.assertEqual(self.podcast.language, language)
        self.assertEqual(self.podcast.last_build_date, last_build_date)
        self.assertEqual(self.podcast.link, link)
        self.assertEqual(self.podcast.managing_editor, managing_editor)
        self.assertEqual(self.podcast.new_feed_url, new_feed_url)
        self.assertEqual(self.podcast.owner, owner)
        self.assertEqual(self.podcast.pub_date, pub_date)
        self.assertEqual(self.podcast.subtitle, subtitle)
        self.assertEqual(self.podcast.summary, summary)
        self.assertEqual(self.podcast.title, title)
        self.assertEqual(self.podcast.type, _type)
        self.assertEqual(self.podcast.web_master, web_master)

if __name__ == "__main__":
    unittest.main()



from __future__ import division, absolute_import, print_function
from collections import OrderedDict
from xml.etree.ElementTree import fromstring
from xmljson import badgerfish as bf
import os
import xml.etree.ElementTree as ET

from podcasts.log import logger

class Podcast:
    def __init__(self, source):
        """Initializes a Podcast instance based on XML data from a string or file path"""

        logger.debug("Initializing podcast from source: " + source)

        if os.path.isfile(source):
            tree = ET.parse(source)
            root = tree.getroot()
            data = bf.data(root)
        else:
            data = bf.data(fromstring(source))

        channel = data.get("rss").get("channel")

        self.source = source
        self.channel = channel
        self.author = channel.get("author", {}).get("$")
        self.copyright = channel.get("copyright", {}).get("$")
        self.description = channel.get("description", {}).get("$")
        self.explicit = channel.get("explicit", {}).get("$")
        self.generator = channel.get("generator", {}).get("$")
        self.language = channel.get("language", {}).get("$")
        self.managing_editor = channel.get("managingEditor", {}).get("$")
        self.new_feed_url = channel.get("new-feed-url", {}).get("$")
        self.pub_date = channel.get("pubDate", {}).get("$")
        self.subtitle = channel.get("subtitle", {}).get("$")
        self.summary = channel.get("summary", {}).get("$")
        self.title = channel.get("title", {}).get("$")
        self.type = channel.get("type", {}).get("$")
        self.web_master = channel.get("webMaster", {}).get("$")

    def __str__(self):
        return self.source

    @property
    def link(self):
        channel = self.channel
        channel_links = channel.get("link")

        link = None

        if channel_links and isinstance(channel_links, OrderedDict):
            channel_links = [channel_links]

        for channel_link in channel_links:
            if channel_link.get("$"):
                link = channel_link.get("$")
                break

        logger.debug("Link: " + link)
        return link

    @property
    def owner(self):
        channel = self.channel
        channel_owner = channel.get("owner")

        owner = None

        if channel_owner and isinstance(channel_owner, OrderedDict):
            owner_value = channel_owner.get("$")

            if owner_value and isinstance(owner_value, str):
                owner = owner_value

        if not owner and channel_owner.get("name"):
            owner = channel_owner.get("name", {}).get("$")

        if not owner and channel_owner.get("email"):
            owner = channel_owner.get("email", {}).get("$")

        logger.debug("Onwer: " + owner)
        return owner

    @property
    def image_url(self):
        """Finds and return the feed's image URL"""

        channel = self.channel
        
        channel_images = channel.get("image")

        image_url = None

        # get itunes image if it exists
        itunes_image = "{http://www.itunes.com/dtds/podcast-1.0.dtd}image"
        if channel.get(itunes_image):
            logger.debug("Using feed's iTunes image for image_url")
            image_url = channel.get(itunes_image).get("@href")

        # put channel_images into a list if there's only one
        if channel_images and isinstance(channel_images, OrderedDict):
            channel_images = [channel_images]

        # get channel image if they exists
        for channel_image in channel_images:
            if not image_url and channel_image.get("url"):
                image_url = channel_image.get("url").get("$")

            if not image_url and channel_image.get("@href"):
                image_url = channel_image.get("@href")

        logger.debug("Image URL: " + image_url)
        return image_url

    @property
    def last_build_date(self):
        """Returns the feed's lastBuildDate if it exists, otherwise return the first episode's pubDate"""

        channel = self.channel
        last_build_date = None

        if channel.get("lastBuildDate"):
            logger.debug("Using feed's lastBuildDate")
            last_build_date = channel.get("lastBuildDate", {}).get("$")

        items = channel.get("item")
        latest_item = items[0]
        if not last_build_date and latest_item and latest_item.get("pubDate"):
            logger.debug("Using latest episode's pubDate")
            last_build_date =  latest_item.get("pubDate", {}).get("$")

        logger.debug("Last build date: " + last_build_date)
        return last_build_date

    @property
    def categories(self):
        """Returns a list of the feed's categories"""

        channel = self.channel

        categories = []

        categories = channel.get("category")
        if not categories:
            logger.warning("Channel has no categories")
            return

        if categories and isinstance(categories, OrderedDict):
            categories = [categories]

        for category in categories:
            logger.debug("Parsing category: " + str(category))

            if isinstance(category, str):
                categories = categories + [category]

            if isinstance(category, OrderedDict):
                categories = categories + [category.get("@text"), category.get("$")]

                if category.get("category"):
                    for inner_category in category.get("category"):
                        if isinstance(inner_category, str):
                            categories = categories + [inner_category]

                        if isinstance(inner_category, OrderedDict):
                            categories = categories + [inner_category.get("@text"), inner_category.get("$")]
        
        categories[:] = [category for category in categories if isinstance(category, str) and category != "@text"]
        categories = list(set(categories))
        categories.sort()

        logger.debug("Categories found: " + str(categories))

        return categories



#!/usr/bin/env python
from __future__ import division, absolute_import, print_function

import os
import sys
import unittest


cwd = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, cwd)

from podcasts import Podcast

source = os.path.join(cwd, "test", "fixtures", "megaphone.xml")

author = "iHeartRadio & HowStuffWorks"
_copyright = "Copyright 2015 HowStuffWorks"
description = "If you've ever wanted to know about champagne, satanism, the Stonewall Uprising, chaos theory, LSD, El Nino, true crime and Rosa Parks then look no further. Josh and Chuck have you covered."
explicit = "no"
generator = None
language = "en"
link = "https://www.howstuffworks.com"
managing_editor = None
new_feed_url = "https://feeds.megaphone.fm/stuffyoushouldknow"
pub_date = None
subtitle = "Stuff You Should Know"
summary = "If you've ever wanted to know about champagne, satanism, the Stonewall Uprising, chaos theory, LSD, El Nino, true crime and Rosa Parks then look no further. Josh and Chuck have you covered."
title = "Stuff You Should Know"
_type = "episodic"
web_master = None
categories = ['Society & Culture']
image_url = "https://static.megaphone.fm/podcasts/1e705dd4-2de6-11e8-b55d-9ba6ddb3f75e/image/uploads_2F1546996139536-0o3pw93d8mk-d5f1143c14a746754c55efb478c66988_2FSKSKLogo-FINAL-iHR-3000x3000.png"
last_build_date = "Sat, 11 May 2019 09:00:00 -0000"
owner = "iHeartRadio & HowStuffWorks"

class TestMegaphone(unittest.TestCase):
    def setUp(self):
        self.podcast = Podcast(source)

    def test_attrubites(self):

        self.assertEqual(self.podcast.source, source)
        self.assertEqual(self.podcast.author, author)
        self.assertEqual(self.podcast.categories, categories)
        self.assertEqual(self.podcast.copyright, _copyright)
        self.assertEqual(self.podcast.description, description)
        self.assertEqual(self.podcast.explicit, explicit)
        self.assertEqual(self.podcast.generator, generator)
        self.assertEqual(self.podcast.image_url, image_url)
        self.assertEqual(self.podcast.language, language)
        self.assertEqual(self.podcast.last_build_date, last_build_date)
        self.assertEqual(self.podcast.link, link)
        self.assertEqual(self.podcast.managing_editor, managing_editor)
        self.assertEqual(self.podcast.new_feed_url, new_feed_url)
        self.assertEqual(self.podcast.owner, owner)
        self.assertEqual(self.podcast.pub_date, pub_date)
        self.assertEqual(self.podcast.subtitle, subtitle)
        self.assertEqual(self.podcast.summary, summary)
        self.assertEqual(self.podcast.title, title)
        self.assertEqual(self.podcast.type, _type)
        self.assertEqual(self.podcast.web_master, web_master)

if __name__ == "__main__":
    unittest.main()



#!/usr/bin/env python
from __future__ import division, absolute_import, print_function

import os
import sys
import unittest


cwd = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, cwd)

from podcasts import Podcast

source = os.path.join(cwd, "test", "fixtures", "libsyn.xml")

_copyright = "Copyright © Talking Monkey Productions"
_type = "episodic"
author = "Joe Rogan"
categories = ['Comedy', 'Society & Culture', 'Technology']
description = "Conduit to the Gaian Mind"
explicit = "yes"
generator = "Libsyn WebEngine 2.0"
image_url = "http://static.libsyn.com/p/assets/7/1/f/3/71f3014e14ef2722/JREiTunesImage2.jpg"
language = "en"
last_build_date = "Fri, 10 May 2019 02:04:10 +0000"
link = "https://www.joerogan.com"
managing_editor = "joe@joerogan.net (joe@joerogan.net)"
new_feed_url = "http://joeroganexp.joerogan.libsynpro.com/rss"
owner = "Joe Rogan"
pub_date = "Fri, 10 May 2019 02:00:00 +0000"
subtitle = "Joe Rogan's Weekly Podcast"
summary = "The podcast of Comedian Joe Rogan.."
title = "The Joe Rogan Experience"
web_master = None

class TestLibsyn(unittest.TestCase):
    def setUp(self):
        self.podcast = Podcast(source)

    def test_attrubites(self):

        self.assertEqual(self.podcast.source, source)
        self.assertEqual(self.podcast.author, author)
        self.assertEqual(self.podcast.categories, categories)
        self.assertEqual(self.podcast.copyright, _copyright)
        self.assertEqual(self.podcast.description, description)
        self.assertEqual(self.podcast.explicit, explicit)
        self.assertEqual(self.podcast.generator, generator)
        self.assertEqual(self.podcast.image_url, image_url)
        self.assertEqual(self.podcast.language, language)
        self.assertEqual(self.podcast.last_build_date, last_build_date)
        self.assertEqual(self.podcast.link, link)
        self.assertEqual(self.podcast.managing_editor, managing_editor)
        self.assertEqual(self.podcast.new_feed_url, new_feed_url)
        self.assertEqual(self.podcast.owner, owner)
        self.assertEqual(self.podcast.pub_date, pub_date)
        self.assertEqual(self.podcast.subtitle, subtitle)
        self.assertEqual(self.podcast.summary, summary)
        self.assertEqual(self.podcast.title, title)
        self.assertEqual(self.podcast.type, _type)
        self.assertEqual(self.podcast.web_master, web_master)

if __name__ == "__main__":
    unittest.main()



#!/usr/bin/env python3
# -*- encoding: utf-8 -*-

from setuptools import setup, find_packages

import podcasts

setup(
    name="podcasts",
    version="0.0.5",
    packages=find_packages(),
    author="Jorrin Pollard",
    author_email="hi@jorr.in",
    description="Parse podcasts with Python",
    url="https://github.com/jorrinpollard/podcasts",
    long_description="README at https://github.com/jorrinpollard/podcasts",
    license="MIT",
    classifiers=[
        "Development Status :: 1 - Planning",
        "Environment :: Console",
        "Intended Audience :: End Users/Desktop",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Multimedia :: Sound/Audio",
    ],
    keywords=["podcasts"],
    install_requires=["xmljson"],
)



from __future__ import division, absolute_import, print_function
from logging import handlers
import logging
import sys

logger = logging.getLogger(__name__)

stream_handler = logging.StreamHandler(sys.stdout)
stream_handler.setFormatter(
    logging.Formatter("%(asctime)s [ podcasts | %(levelname)-5.5s] %(message)s")
)

logger.addHandler(stream_handler)
logger.setLevel(logging.DEBUG)



#!/usr/bin/env python
from __future__ import division, absolute_import, print_function

import os
import sys
import unittest


cwd = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, cwd)

from podcasts import Podcast

source = os.path.join(cwd, "test", "fixtures", "feedburner.xml")

_copyright = "Copyright 2019 Serial Podcast"
_type = "serial"
author = "This American Life"
categories = ["News & Politics"]
description = "Serial is a podcast from the creators of This American Life, hosted by Sarah Koenig. Serial unfolds one story - a true story - over the course of a whole season. The show follows the plot and characters wherever they lead, through many surprising twists and turns. Sarah won't know what happens at the end of the story until she gets there, not long before you get there with her. Each week she'll bring you the latest chapter, so it's important to listen in, starting with Episode 1. New episodes are released on Thursday mornings."
explicit = None
generator = None
image_url = "https://serialpodcast.org/sites/all/modules/custom/serial/img/serial-itunes-logo.png"
language = "en"
last_build_date = "Thu, 15 Nov 2018 10:30:00 +0000"
managing_editor = None
new_feed_url = None
owner = "rich@thislife.org"
pub_date = None
subtitle = "A podcast from the creators of This American Life"
summary = None
title = "Serial"
web_master = None
link = "https://serialpodcast.org"

class TestFeedburner(unittest.TestCase):
    def setUp(self):
        self.podcast = Podcast(source)

    def test_attrubites(self):

        self.assertEqual(self.podcast.source, source)
        self.assertEqual(self.podcast.author, author)
        self.assertEqual(self.podcast.categories, categories)
        self.assertEqual(self.podcast.copyright, _copyright)
        self.assertEqual(self.podcast.description, description)
        self.assertEqual(self.podcast.explicit, explicit)
        self.assertEqual(self.podcast.generator, generator)
        self.assertEqual(self.podcast.image_url, image_url)
        self.assertEqual(self.podcast.language, language)
        self.assertEqual(self.podcast.last_build_date, last_build_date)
        self.assertEqual(self.podcast.link, link)
        self.assertEqual(self.podcast.managing_editor, managing_editor)
        self.assertEqual(self.podcast.new_feed_url, new_feed_url)
        self.assertEqual(self.podcast.owner, owner)
        self.assertEqual(self.podcast.pub_date, pub_date)
        self.assertEqual(self.podcast.subtitle, subtitle)
        self.assertEqual(self.podcast.summary, summary)
        self.assertEqual(self.podcast.title, title)
        self.assertEqual(self.podcast.type, _type)
        self.assertEqual(self.podcast.web_master, web_master)

if __name__ == "__main__":
    unittest.main()



#!/usr/bin/env python
from __future__ import division, absolute_import, print_function

import os
import sys
import unittest


cwd = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, cwd)

from podcasts import Podcast

source = os.path.join(cwd, "test", "fixtures", "art19.xml")

_copyright = None
_type = "episodic"
author = "GaS Digital Network"
categories = ['Sports & Recreation']
description = "<p>For the past two years, UFC middleweight Champion, Michael Bisping, and stand up comedian, Luis J. Gomez, have hosted a show together on satellite radio. Now they bring their brand of brash, comedic MMA commentary to the podcast world! Believe You Me is a weekly show that gives you a behind the scenes look at the career and life of a UFC champion. Bisping along with his co-host, Gomez, break down MMA news, pop culture stories, and talk parenting, philosophy, and life in general. Believe You Me is FOR ADULTS ONLY! Follow us on twitter and Instagram: @BYMPod. The newest 15 episodes are always free, but if you want access to all the archives, listen live, chat live, access to the forums, and get the show before it comes out everywhere else - you can subscribe now at gasdigitalnetwork.com and use the code BYM to save 15% on the entire network.</p>"
explicit = "yes"
generator = "ART19"
image_url = "https://content.production.cdn.art19.com/images/61/e2/04/17/61e20417-ab6f-43c6-a8fb-00d8d845d8e5/d7bea48af84622089cf34d61a6b2bd64691ac4bda05793a4ca463ea0afbb60bc8af9457ea259ebe8d79826bf2e48d510d6fc130edd74e0bb5454fc1ee30baf74.jpeg"
language = "en"
last_build_date = "Tue, 07 May 2019 04:44:41 -0000"
link = "http://GaSDigitalNetwork.com/believe"
managing_editor = "bym@gasdigitalnetwork.com (Michael Bisping, Luis J. Gomez)"
new_feed_url = "https://rss.art19.com/believe-you-me"
owner = "Michael Bisping, Luis J. Gomez"
pub_date = None
subtitle = None
summary = "<p>For the past two years, UFC middleweight Champion, Michael Bisping, and stand up comedian, Luis J. Gomez, have hosted a show together on satellite radio. Now they bring their brand of brash, comedic MMA commentary to the podcast world! Believe You Me is a weekly show that gives you a behind the scenes look at the career and life of a UFC champion. Bisping along with his co-host, Gomez, break down MMA news, pop culture stories, and talk parenting, philosophy, and life in general. Believe You Me is FOR ADULTS ONLY! Follow us on twitter and Instagram: @BYMPod. The newest 15 episodes are always free, but if you want access to all the archives, listen live, chat live, access to the forums, and get the show before it comes out everywhere else - you can subscribe now at gasdigitalnetwork.com and use the code BYM to save 15% on the entire network.</p>"
title = "Believe You Me with Michael Bisping"
web_master = None

class TestArt19(unittest.TestCase):
    def setUp(self):
        self.podcast = Podcast(source)

    def test_attrubites(self):

        self.assertEqual(self.podcast.source, source)
        self.assertEqual(self.podcast.author, author)
        self.assertEqual(self.podcast.categories, categories)
        self.assertEqual(self.podcast.copyright, _copyright)
        self.assertEqual(self.podcast.description, description)
        self.assertEqual(self.podcast.explicit, explicit)
        self.assertEqual(self.podcast.generator, generator)
        self.assertEqual(self.podcast.image_url, image_url)
        self.assertEqual(self.podcast.language, language)
        self.assertEqual(self.podcast.last_build_date, last_build_date)
        self.assertEqual(self.podcast.link, link)
        self.assertEqual(self.podcast.managing_editor, managing_editor)
        self.assertEqual(self.podcast.new_feed_url, new_feed_url)
        self.assertEqual(self.podcast.owner, owner)
        self.assertEqual(self.podcast.pub_date, pub_date)
        self.assertEqual(self.podcast.subtitle, subtitle)
        self.assertEqual(self.podcast.summary, summary)
        self.assertEqual(self.podcast.title, title)
        self.assertEqual(self.podcast.type, _type)
        self.assertEqual(self.podcast.web_master, web_master)

if __name__ == "__main__":
    unittest.main()



#!/usr/bin/env python
from __future__ import division, absolute_import, print_function

import os
import sys
import unittest


cwd = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, cwd)

from podcasts import Podcast

source = os.path.join(cwd, "test", "fixtures", "barstool.xml")

_copyright = "2019 Barstool Sports"
_type = None
author = "Barstool Sports"
categories = ['Comedy', 'Talk Radio']
description = "Follow along vlogger Alexandra Cooper and best friend Sofia Franklyn as the duo dives into the explicit details of their life in NYC. In their 20s, the two exploit the f*ck out of their lives, making you feel a hell of a lot better about yours. Relationships, sex, the NY social scene, embarrassing moments, and more are all addressed here on CALL HER DADDY."
explicit = "yes"
generator = "McSorleys by Barstool Sports"
image_url = "https://podcasts.barstoolsports.com/_images/call_her_daddy_itunes.e5b5d9abdc67.jpg"
language = "en-us"
last_build_date = "Sat, 11 May 2019 20:27:55 GMT"
link = "https://www.barstoolsports.com/shows/call-her-daddy"
managing_editor = "podcasting@barstoolsports.com (Barstool Podcasting)"
new_feed_url = "https://mcsorleys.barstoolsports.com/feed/call-her-daddy"
owner = "Barstool Sports"
pub_date = "Sun, 20 May 2012 04:00:00 GMT"
subtitle = "Follow along vlogger Alexandra Cooper and best friend Sofia Franklyn as the duo dives into the explicit details of their life in NYC. In their 20s, the two exploit the f*ck out of their lives, making you feel a hell of a lot better about yours. Relationsh"
summary = "Follow along vlogger Alexandra Cooper and best friend Sofia Franklyn as the duo dives into the explicit details of their life in NYC. In their 20s, the two exploit the f*ck out of their lives, making you feel a hell of a lot better about yours. Relationships, sex, the NY social scene, embarrassing moments, and more are all addressed here on CALL HER DADDY."
title = "Call Her Daddy"
web_master = "engineering@barstoolsports.com (Barstool Engineering)"

class TestBarstool(unittest.TestCase):
    def setUp(self):
        self.podcast = Podcast(source)

    def test_attrubites(self):

        self.assertEqual(self.podcast.source, source)
        self.assertEqual(self.podcast.author, author)
        self.assertEqual(self.podcast.categories, categories)
        self.assertEqual(self.podcast.copyright, _copyright)
        self.assertEqual(self.podcast.description, description)
        self.assertEqual(self.podcast.explicit, explicit)
        self.assertEqual(self.podcast.generator, generator)
        self.assertEqual(self.podcast.image_url, image_url)
        self.assertEqual(self.podcast.language, language)
        self.assertEqual(self.podcast.last_build_date, last_build_date)
        self.assertEqual(self.podcast.link, link)
        self.assertEqual(self.podcast.managing_editor, managing_editor)
        self.assertEqual(self.podcast.new_feed_url, new_feed_url)
        self.assertEqual(self.podcast.owner, owner)
        self.assertEqual(self.podcast.pub_date, pub_date)
        self.assertEqual(self.podcast.subtitle, subtitle)
        self.assertEqual(self.podcast.summary, summary)
        self.assertEqual(self.podcast.title, title)
        self.assertEqual(self.podcast.type, _type)
        self.assertEqual(self.podcast.web_master, web_master)

if __name__ == "__main__":
    unittest.main()
